@@ -1028,7 +1028,8 @@ get_folders (TrackerSparqlConnection *connection,
 		query = g_strdup_printf ("SELECT ?u nie:isStoredAs(?u) "
 		                         "WHERE { "
 		                         "  ?u a nfo:Folder ;"
-		                         "  fts:match \"%s\" ."
+		                         "  nie:isStoredAs ?url ."
+		                         "  ?url fts:match \"%s\" ."
 		                         "  %s"
 		                         "} "
 		                         "ORDER BY ASC(nie:isStoredAs(?u)) "
